@@ -37,18 +37,19 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     self.add(self.__smi_box)
     ilist = enumerate(ifaces)
 
-    loaded_list = ''
-    loaded_ifaces = 0
+    #loaded_list = ''
+    #loaded_ifaces = 0
     for iface in ilist:
       try:
         self.__interfaces.append(iface[1](self.__bus, self.process_sai))
         self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), iface[0], iface[0]+1, 0, 1, gtk.EXPAND | gtk.FILL, gtk.SHRINK)
-        loaded_ifaces += 1
-        loaded_list = '%s\n%s' % (loaded_list, self.__interfaces[iface[0]].get_name())
+        #loaded_ifaces += 1
+        #loaded_list = '%s\n%s' % (loaded_list, self.__interfaces[iface[0]].get_name())
       except Exception, e:
-        print 'Error: %s' % (e)
-    print 'Loaded (%s/%s):%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
-
+        pass
+        loaded_list = '%s\nError: %s' % (loaded_list, e)
+    #result = 'Loaded (%s/%s):%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
+    #print result
     self.show_all()
 
   def process_sai(self, iname, image='', add=True):
